@@ -445,7 +445,8 @@ test_that("transform_attribute_format() update_according_to", {
       "      width = 5,",
       "      decimal_places = 2,",
       "      k_sep = ',',",
-      "      decimal_sep = '.'",
+      "      decimal_sep = '.',",
+      "      space_filling = TRUE",
       "    )",
       "",
       "  ft",
